@@ -70,20 +70,21 @@ public class NotificationHelper {
                     .setCategory(NotificationCompat.CATEGORY_SERVICE)
                     .setDeleteIntent(piStop)
                     .setContentIntent(spi)
-                    .addAction(R.drawable.ic_previous_w, ctx.getString(R.string.previous), piBackward);
+                    .addAction(R.drawable.ic_widget_previous_w, ctx.getString(R.string.previous), piBackward);
             if (playing)
-                builder.addAction(R.drawable.ic_pause_w, ctx.getString(R.string.pause), piPlay);
+                builder.addAction(R.drawable.ic_widget_pause_w, ctx.getString(R.string.pause), piPlay);
             else
-                builder.addAction(R.drawable.ic_play_w, ctx.getString(R.string.play), piPlay);
-            builder.addAction(R.drawable.ic_next_w, ctx.getString(R.string.next), piForward);
+                builder.addAction(R.drawable.ic_widget_play_w, ctx.getString(R.string.play), piPlay);
+            builder.addAction(R.drawable.ic_widget_next_w, ctx.getString(R.string.next), piForward);
+            builder.addAction(R.drawable.ic_widget_close_w, ctx.getString(R.string.stop), piStop);
 
             if (AndroidDevices.showMediaStyle) {
-                builder.setStyle(new Notification.MediaStyle()
-                        .setMediaSession((MediaSession.Token) sessionToken.getToken())
-                        .setShowActionsInCompactView(0,1,2)
-                );
+                final Notification.MediaStyle ms = new Notification.MediaStyle()
+                        .setShowActionsInCompactView(0,1,2);
+                if (sessionToken != null)
+                    ms.setMediaSession((MediaSession.Token) sessionToken.getToken());
+                builder.setStyle(ms);
             }
-            ctx.startForegroundService(new Intent(ctx, PlaybackService.class));
             return builder.build();
         } else {
             final NotificationCompat.Builder builder = new NotificationCompat.Builder(ctx);
@@ -98,12 +99,13 @@ public class NotificationHelper {
                     .setCategory(NotificationCompat.CATEGORY_SERVICE)
                     .setDeleteIntent(piStop)
                     .setContentIntent(spi)
-                    .addAction(R.drawable.ic_previous_w, ctx.getString(R.string.previous), piBackward);
+                    .addAction(R.drawable.ic_widget_previous_w, ctx.getString(R.string.previous), piBackward);
             if (playing)
-                builder.addAction(R.drawable.ic_pause_w, ctx.getString(R.string.pause), piPlay);
+                builder.addAction(R.drawable.ic_widget_pause_w, ctx.getString(R.string.pause), piPlay);
             else
-                builder.addAction(R.drawable.ic_play_w, ctx.getString(R.string.play), piPlay);
-            builder.addAction(R.drawable.ic_next_w, ctx.getString(R.string.next), piForward);
+                builder.addAction(R.drawable.ic_widget_play_w, ctx.getString(R.string.play), piPlay);
+            builder.addAction(R.drawable.ic_widget_next_w, ctx.getString(R.string.next), piForward);
+            builder.addAction(R.drawable.ic_widget_close_w, ctx.getString(R.string.stop), piStop);
             if (AndroidDevices.showMediaStyle) {
                 builder.setStyle(new NotificationCompat.MediaStyle()
                         .setMediaSession(sessionToken)
@@ -112,7 +114,6 @@ public class NotificationHelper {
                         .setCancelButtonIntent(piStop)
                 );
             }
-            ctx.startService(new Intent(ctx, PlaybackService.class));
             return builder.build();
         }
     }
