@@ -20,12 +20,12 @@
 
 package org.videolan.vlc.util;
 
+import android.text.TextUtils;
+
 import org.videolan.vlc.BuildConfig;
 
 import java.text.DecimalFormat;
-import java.text.NumberFormat;
 import java.util.List;
-import java.util.Locale;
 
 public class Strings {
     public final static String TAG = "VLC/UiTools/Strings";
@@ -50,64 +50,6 @@ public class Strings {
         return -1;
     }
 
-    /**
-     * Convert time to a string
-     * @param millis e.g.time/length from file
-     * @return formated string (hh:)mm:ss
-     */
-    public static String millisToString(long millis)
-    {
-        return Strings.millisToString(millis, false);
-    }
-
-    /**
-     * Convert time to a string
-     * @param millis e.g.time/length from file
-     * @return formated string "[hh]h[mm]min" / "[mm]min[s]s"
-     */
-    public static String millisToText(long millis)
-    {
-        return Strings.millisToString(millis, true);
-    }
-
-    static String millisToString(long millis, boolean text) {
-        boolean negative = millis < 0;
-        millis = java.lang.Math.abs(millis);
-
-        millis /= 1000;
-        int sec = (int) (millis % 60);
-        millis /= 60;
-        int min = (int) (millis % 60);
-        millis /= 60;
-        int hours = (int) millis;
-
-        String time;
-        DecimalFormat format = (DecimalFormat)NumberFormat.getInstance(Locale.US);
-        format.applyPattern("00");
-        if (text) {
-            if (millis > 0)
-                time = (negative ? "-" : "") + hours + "h" + format.format(min) + "min";
-            else if (min > 0)
-                time = (negative ? "-" : "") + min + "min";
-            else
-                time = (negative ? "-" : "") + sec + "s";
-        }
-        else {
-            if (millis > 0)
-                time = (negative ? "-" : "") + hours + ":" + format.format(min) + ":" + format.format(sec);
-            else
-                time = (negative ? "-" : "") + min + ":" + format.format(sec);
-        }
-        return time;
-    }
-
-    /**
-     * equals() with two strings where either could be null
-     */
-    public static boolean nullEquals(String s1, String s2) {
-        return (s1 == null ? s2 == null : s1.equals(s2));
-    }
-
     /**
      * Get the formatted current playback speed in the form of 1.00x
      */
@@ -141,4 +83,11 @@ public class Strings {
     public static String buildPkgString(String string) {
         return BuildConfig.APPLICATION_ID + "." + string;
     }
+
+    public static boolean stringArrayContains(String[] array, String string) {
+        for (int i = 0 ; i < array.length ; ++i)
+            if (TextUtils.equals(string, array[i]))
+                return true;
+        return false;
+    }
 }
